@@ -1,6 +1,6 @@
 /* GDB parameters implemented in Guile.
 
-   Copyright (C) 2008-2022 Free Software Foundation, Inc.
+   Copyright (C) 2008-2023 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -75,9 +75,15 @@ struct param_smob
   /* One of the COMMAND_* constants.  */
   enum command_class cmd_class;
 
+  /* Guile parameter type name.  */
+  const char *pname;
+
   /* The type of the parameter.  */
   enum var_types type;
 
+  /* Extra literals, such as `unlimited', accepted in lieu of a number.  */
+  const literal_def *extra_literals;
+
   /* The docs for the parameter.  */
   char *set_doc;
   char *show_doc;
@@ -95,7 +101,7 @@ struct param_smob
      space, it will be freed with the smob.  */
   const char * const *enumeration;
 
-  /* The set_func funcion or #f if not specified.
+  /* The set_func function or #f if not specified.
      This function is called *after* the parameter is set.
      It returns a string that will be displayed to the user.  */
   SCM set_func;
@@ -110,6 +116,49 @@ struct param_smob
   SCM containing_scm;
 };
 
+/* Guile parameter types as in PARAMETER_TYPES later on.  */
+
+enum scm_param_types
+{
+  param_boolean,
+  param_auto_boolean,
+  param_zinteger,
+  param_uinteger,
+  param_zuinteger,
+  param_zuinteger_unlimited,
+  param_string,
+  param_string_noescape,
+  param_optional_filename,
+  param_filename,
+  param_enum,
+};
+
+/* Translation from Guile parameters to GDB variable types.  Keep in the
+   same order as SCM_PARAM_TYPES due to C++'s lack of designated initializers.  */
+
+static const struct
+{
+  /* The type of the parameter.  */
+  enum var_types type;
+
+  /* Extra literals, such as `unlimited', accepted in lieu of a number.  */
+  const literal_def *extra_literals;
+}
+param_to_var[] =
+{
+  { var_boolean },
+  { var_auto_boolean },
+  { var_integer },
+  { var_uinteger, uinteger_unlimited_literals },
+  { var_uinteger },
+  { var_pinteger, pinteger_unlimited_literals },
+  { var_string },
+  { var_string_noescape },
+  { var_optional_filename },
+  { var_filename },
+  { var_enum }
+};
+
 /* Wraps a setting around an existing param_smob.  This abstraction
    is used to manipulate the value in S->VALUE in a type safe manner using
    the setting interface.  */
@@ -117,18 +166,20 @@ struct param_smob
 static setting
 make_setting (param_smob *s)
 {
-  if (var_type_uses<bool> (s->type))
-    return setting (s->type, &s->value.boolval);
-  else if (var_type_uses<int> (s->type))
-    return setting (s->type, &s->value.intval);
-  else if (var_type_uses<auto_boolean> (s->type))
-    return setting (s->type, &s->value.autoboolval);
-  else if (var_type_uses<unsigned int> (s->type))
-    return setting (s->type, &s->value.uintval);
-  else if (var_type_uses<std::string> (s->type))
-    return setting (s->type, s->value.stringval);
-  else if (var_type_uses<const char *> (s->type))
-    return setting (s->type, &s->value.cstringval);
+  enum var_types type = s->type;
+
+  if (var_type_uses<bool> (type))
+    return setting (type, &s->value.boolval);
+  else if (var_type_uses<int> (type))
+    return setting (type, &s->value.intval, s->extra_literals);
+  else if (var_type_uses<auto_boolean> (type))
+    return setting (type, &s->value.autoboolval);
+  else if (var_type_uses<unsigned int> (type))
+    return setting (type, &s->value.uintval, s->extra_literals);
+  else if (var_type_uses<std::string> (type))
+    return setting (type, s->value.stringval);
+  else if (var_type_uses<const char *> (type))
+    return setting (type, &s->value.cstringval);
   else
     gdb_assert_not_reached ("unhandled var type");
 }
@@ -149,10 +200,9 @@ static SCM set_doc_keyword;
 static SCM show_doc_keyword;
 static SCM initial_value_keyword;
 static SCM auto_keyword;
-static SCM unlimited_keyword;
 
 static int pascm_is_valid (param_smob *);
-static const char *pascm_param_type_name (enum var_types type);
+static const char *pascm_param_type_name (enum scm_param_types type);
 static SCM pascm_param_value (const setting &var, int arg_pos,
 			      const char *func_name);
 
@@ -171,7 +221,7 @@ pascm_print_param_smob (SCM self, SCM port, scm_print_state *pstate)
   if (! pascm_is_valid (p_smob))
     scm_puts (" {invalid}", port);
 
-  gdbscm_printf (port, " %s ", pascm_param_type_name (p_smob->type));
+  gdbscm_printf (port, " %s ", p_smob->pname);
 
   value = pascm_param_value (make_setting (p_smob), GDBSCM_ARG_NONE, NULL);
   scm_display (value, port);
@@ -369,7 +419,9 @@ pascm_show_func (struct ui_file *file, int from_tty,
    function.  */
 
 static set_show_commands
-add_setshow_generic (enum var_types param_type, enum command_class cmd_class,
+add_setshow_generic (enum var_types param_type,
+		     const literal_def *extra_literals,
+		     enum command_class cmd_class,
 		     char *cmd_name, param_smob *self,
 		     char *set_doc, char *show_doc, char *help_doc,
 		     cmd_func_ftype *set_func,
@@ -398,34 +450,28 @@ add_setshow_generic (enum var_types param_type, enum command_class cmd_class,
 
     case var_uinteger:
       commands = add_setshow_uinteger_cmd (cmd_name, cmd_class,
-					   &self->value.uintval, set_doc,
+					   &self->value.uintval,
+					   extra_literals, set_doc,
 					   show_doc, help_doc, set_func,
 					   show_func, set_list, show_list);
       break;
 
-    case var_zinteger:
-      commands = add_setshow_zinteger_cmd (cmd_name, cmd_class,
-					   &self->value.intval, set_doc,
+    case var_integer:
+      commands = add_setshow_integer_cmd (cmd_name, cmd_class,
+					  &self->value.intval,
+					  extra_literals, set_doc,
+					  show_doc, help_doc, set_func,
+					  show_func, set_list, show_list);
+      break;
+
+    case var_pinteger:
+      commands = add_setshow_pinteger_cmd (cmd_name, cmd_class,
+					   &self->value.intval,
+					   extra_literals, set_doc,
 					   show_doc, help_doc, set_func,
 					   show_func, set_list, show_list);
       break;
 
-    case var_zuinteger:
-      commands = add_setshow_zuinteger_cmd (cmd_name, cmd_class,
-					    &self->value.uintval, set_doc,
-					    show_doc, help_doc, set_func,
-					    show_func, set_list, show_list);
-      break;
-
-    case var_zuinteger_unlimited:
-      commands = add_setshow_zuinteger_unlimited_cmd (cmd_name, cmd_class,
-						      &self->value.intval,
-						      set_doc, show_doc,
-						      help_doc, set_func,
-						      show_func, set_list,
-						      show_list);
-      break;
-
     case var_string:
       commands = add_setshow_string_cmd (cmd_name, cmd_class,
 					 self->value.stringval, set_doc,
@@ -532,19 +578,17 @@ compute_enum_list (SCM enum_values_scm, int arg_pos, const char *func_name)
 
 static const scheme_integer_constant parameter_types[] =
 {
-  /* Note: var_integer is deprecated, and intentionally does not
-     appear here.  */
-  { "PARAM_BOOLEAN", var_boolean }, /* ARI: var_boolean */
-  { "PARAM_AUTO_BOOLEAN", var_auto_boolean },
-  { "PARAM_ZINTEGER", var_zinteger },
-  { "PARAM_UINTEGER", var_uinteger },
-  { "PARAM_ZUINTEGER", var_zuinteger },
-  { "PARAM_ZUINTEGER_UNLIMITED", var_zuinteger_unlimited },
-  { "PARAM_STRING", var_string },
-  { "PARAM_STRING_NOESCAPE", var_string_noescape },
-  { "PARAM_OPTIONAL_FILENAME", var_optional_filename },
-  { "PARAM_FILENAME", var_filename },
-  { "PARAM_ENUM", var_enum },
+  { "PARAM_BOOLEAN", param_boolean }, /* ARI: param_boolean */
+  { "PARAM_AUTO_BOOLEAN", param_auto_boolean },
+  { "PARAM_ZINTEGER", param_zinteger },
+  { "PARAM_UINTEGER", param_uinteger },
+  { "PARAM_ZUINTEGER", param_zuinteger },
+  { "PARAM_ZUINTEGER_UNLIMITED", param_zuinteger_unlimited },
+  { "PARAM_STRING", param_string },
+  { "PARAM_STRING_NOESCAPE", param_string_noescape },
+  { "PARAM_OPTIONAL_FILENAME", param_optional_filename },
+  { "PARAM_FILENAME", param_filename },
+  { "PARAM_ENUM", param_enum },
 
   END_INTEGER_CONSTANTS
 };
@@ -568,7 +612,7 @@ pascm_valid_parameter_type_p (int param_type)
 /* Return PARAM_TYPE as a string.  */
 
 static const char *
-pascm_param_type_name (enum var_types param_type)
+pascm_param_type_name (enum scm_param_types param_type)
 {
   int i;
 
@@ -588,10 +632,6 @@ pascm_param_type_name (enum var_types param_type)
 static SCM
 pascm_param_value (const setting &var, int arg_pos, const char *func_name)
 {
-  /* Note: We *could* support var_integer here in case someone is trying to get
-     the value of a Python-created parameter (which is the only place that
-     still supports var_integer).  To further discourage its use we do not.  */
-
   switch (var.type ())
     {
     case var_string:
@@ -631,20 +671,29 @@ pascm_param_value (const setting &var, int arg_pos, const char *func_name)
 	  return auto_keyword;
       }
 
-    case var_zuinteger_unlimited:
-      if (var.get<int> () == -1)
-	return unlimited_keyword;
-      gdb_assert (var.get<int> () >= 0);
-      /* Fall through.  */
-    case var_zinteger:
-      return scm_from_int (var.get<int> ());
-
     case var_uinteger:
-      if (var.get<unsigned int> ()== UINT_MAX)
-	return unlimited_keyword;
-      /* Fall through.  */
-    case var_zuinteger:
-      return scm_from_uint (var.get<unsigned int> ());
+    case var_integer:
+    case var_pinteger:
+      {
+	LONGEST value
+	  = (var.type () == var_uinteger
+	     ? static_cast<LONGEST> (var.get<unsigned int> ())
+	     : static_cast<LONGEST> (var.get<int> ()));
+
+	if (var.extra_literals () != nullptr)
+	  for (const literal_def *l = var.extra_literals ();
+	       l->literal != nullptr;
+	       l++)
+	    if (value == l->use)
+	      return scm_from_latin1_keyword (l->literal);
+	if (var.type () == var_pinteger)
+	  gdb_assert (value >= 0);
+
+	if (var.type () == var_uinteger)
+	  return scm_from_uint (static_cast<unsigned int> (value));
+	else
+	  return scm_from_int (static_cast<int> (value));
+      }
 
     default:
       break;
@@ -735,53 +784,91 @@ pascm_set_param_value_x (param_smob *p_smob,
 	var.set<enum auto_boolean> (AUTO_BOOLEAN_FALSE);
       break;
 
-    case var_zinteger:
+    case var_integer:
     case var_uinteger:
-    case var_zuinteger:
-    case var_zuinteger_unlimited:
-      if (var.type () == var_uinteger
-	  || var.type () == var_zuinteger_unlimited)
-	{
-	  SCM_ASSERT_TYPE (scm_is_integer (value)
-			   || scm_is_eq (value, unlimited_keyword),
-			   value, arg_pos, func_name,
-			   _("integer or #:unlimited"));
-	  if (scm_is_eq (value, unlimited_keyword))
+    case var_pinteger:
+      {
+	const literal_def *extra_literals = p_smob->extra_literals;
+	enum tribool allowed = TRIBOOL_UNKNOWN;
+	enum var_types var_type = var.type ();
+	bool integer = scm_is_integer (value);
+	bool keyword = scm_is_keyword (value);
+	std::string buffer = "";
+	size_t count = 0;
+	LONGEST val;
+
+	if (extra_literals != nullptr)
+	  for (const literal_def *l = extra_literals;
+	       l->literal != nullptr;
+	       l++, count++)
 	    {
-	      if (var.type () == var_uinteger)
-		var.set<unsigned int> (UINT_MAX);
-	      else
-		var.set<int> (-1);
-	      break;
+	      if (count != 0)
+		buffer += ", ";
+	      buffer = buffer + "#:" + l->literal;
+	      if (keyword
+		  && allowed == TRIBOOL_UNKNOWN
+		  && scm_is_eq (value,
+				scm_from_latin1_keyword (l->literal)))
+		{
+		  val = l->use;
+		  allowed = TRIBOOL_TRUE;
+		}
 	    }
-	}
-      else
-	{
-	  SCM_ASSERT_TYPE (scm_is_integer (value), value, arg_pos, func_name,
-			   _("integer"));
-	}
 
-      if (var.type () == var_uinteger
-	  || var.type () == var_zuinteger)
-	{
-	  unsigned int u = scm_to_uint (value);
+	if (allowed == TRIBOOL_UNKNOWN)
+	  {
+	    if (extra_literals == nullptr)
+	      SCM_ASSERT_TYPE (integer, value, arg_pos, func_name,
+			       _("integer"));
+	    else if (count > 1)
+	      SCM_ASSERT_TYPE (integer, value, arg_pos, func_name,
+			       string_printf (_("integer or one of: %s"),
+					      buffer.c_str ()).c_str ());
+	    else
+	      SCM_ASSERT_TYPE (integer, value, arg_pos, func_name,
+			       string_printf (_("integer or %s"),
+					      buffer.c_str ()).c_str ());
 
-	  if (var.type () == var_uinteger && u == 0)
-	    u = UINT_MAX;
-	  var.set<unsigned int> (u);
-	}
-      else
-	{
-	  int i = scm_to_int (value);
+	    val = (var_type == var_uinteger
+		   ? static_cast<LONGEST> (scm_to_uint (value))
+		   : static_cast<LONGEST> (scm_to_int (value)));
 
-	  if (var.type () == var_zuinteger_unlimited && i < -1)
-	    {
-	      gdbscm_out_of_range_error (func_name, arg_pos, value,
-					 _("must be >= -1"));
+	    if (extra_literals != nullptr)
+	      for (const literal_def *l = extra_literals;
+		   l->literal != nullptr;
+		   l++)
+		{
+		  if (l->val.has_value () && val == *l->val)
+		    {
+		      allowed = TRIBOOL_TRUE;
+		      val = l->use;
+		      break;
+		    }
+		  else if (val == l->use)
+		    allowed = TRIBOOL_FALSE;
+		}
 	    }
-	  var.set<int> (i);
-	}
-      break;
+
+	if (allowed == TRIBOOL_UNKNOWN)
+	  {
+	    if (val > UINT_MAX || val < INT_MIN
+		|| (var_type == var_uinteger && val < 0)
+		|| (var_type == var_integer && val > INT_MAX)
+		|| (var_type == var_pinteger && val < 0)
+		|| (var_type == var_pinteger && val > INT_MAX))
+	      allowed = TRIBOOL_FALSE;
+	  }
+	if (allowed == TRIBOOL_FALSE)
+	  gdbscm_out_of_range_error (func_name, arg_pos, value,
+				     _("integer out of range"));
+
+	if (var_type == var_uinteger)
+	  var.set<unsigned int> (static_cast<unsigned int> (val));
+	else
+	  var.set<int> (static_cast<int> (val));
+
+	break;
+      }
 
     default:
       gdb_assert_not_reached ("bad parameter type");
@@ -858,7 +945,7 @@ gdbscm_make_parameter (SCM name_scm, SCM rest)
   char *s;
   char *name;
   int cmd_class = no_class;
-  int param_type = var_boolean; /* ARI: var_boolean */
+  int param_type = param_boolean; /* ARI: param_boolean */
   SCM enum_list_scm = SCM_BOOL_F;
   SCM set_func = SCM_BOOL_F, show_func = SCM_BOOL_F;
   char *doc = NULL, *set_doc = NULL, *show_doc = NULL;
@@ -913,12 +1000,12 @@ gdbscm_make_parameter (SCM name_scm, SCM rest)
 				 scm_from_int (param_type),
 				 _("invalid parameter type argument"));
     }
-  if (enum_list_arg_pos > 0 && param_type != var_enum)
+  if (enum_list_arg_pos > 0 && param_type != param_enum)
     {
       gdbscm_misc_error (FUNC_NAME, enum_list_arg_pos, enum_list_scm,
 		_("#:enum-values can only be provided with PARAM_ENUM"));
     }
-  if (enum_list_arg_pos < 0 && param_type == var_enum)
+  if (enum_list_arg_pos < 0 && param_type == param_enum)
     {
       gdbscm_misc_error (FUNC_NAME, GDBSCM_ARG_NONE, SCM_BOOL_F,
 			 _("PARAM_ENUM requires an enum-values argument"));
@@ -933,7 +1020,7 @@ gdbscm_make_parameter (SCM name_scm, SCM rest)
       SCM_ASSERT_TYPE (gdbscm_is_procedure (show_func), show_func,
 		       show_func_arg_pos, FUNC_NAME, _("procedure"));
     }
-  if (param_type == var_enum)
+  if (param_type == param_enum)
     {
       /* Note: enum_list lives in GC space, so we don't have to worry about
 	 freeing it if we later throw an exception.  */
@@ -950,7 +1037,10 @@ gdbscm_make_parameter (SCM name_scm, SCM rest)
      freeing them if we throw an exception.  */
   p_smob->name = name;
   p_smob->cmd_class = (enum command_class) cmd_class;
-  p_smob->type = (enum var_types) param_type;
+  p_smob->pname
+    = pascm_param_type_name (static_cast<enum scm_param_types> (param_type));
+  p_smob->type = param_to_var[param_type].type;
+  p_smob->extra_literals = param_to_var[param_type].extra_literals;
   p_smob->doc = doc;
   p_smob->set_doc = set_doc;
   p_smob->show_doc = show_doc;
@@ -1031,7 +1121,8 @@ gdbscm_register_parameter_x (SCM self)
   try
     {
       p_smob->commands = add_setshow_generic
-	(p_smob->type, p_smob->cmd_class, p_smob->cmd_name, p_smob,
+	(p_smob->type, p_smob->extra_literals,
+	 p_smob->cmd_class, p_smob->cmd_name, p_smob,
 	 p_smob->set_doc, p_smob->show_doc, p_smob->doc,
 	 (gdbscm_is_procedure (p_smob->set_func) ? pascm_set_func : NULL),
 	 (gdbscm_is_procedure (p_smob->show_func) ? pascm_show_func : NULL),
@@ -1203,5 +1294,4 @@ gdbscm_initialize_parameters (void)
   show_doc_keyword = scm_from_latin1_keyword ("show-doc");
   initial_value_keyword = scm_from_latin1_keyword ("initial-value");
   auto_keyword = scm_from_latin1_keyword ("auto");
-  unlimited_keyword = scm_from_latin1_keyword ("unlimited");
 }
